@@ -1,46 +1,31 @@
-## @file
-# Implementation of Chart::Bars
-#
-# written by
-# @author david bonner (dbonner@cs.bu.edu)
-#
-# maintained by the
-# @author Chart Group at Geodetic Fundamental Station Wettzell (Chart@fs.wettzell.de)
-# @date 2015-03-01
-# @version 2.4.10
 
-## @class Chart::Bars
-# Bars class provides all functions which are specific to
 # vertical bars
-use strict;
+
+use v5.12;
 
 package Chart::Bars;
-our $VERSION = 2.400.5;
-@Chart::Bars::ISA     = qw(Chart::Base);
+our @ISA     = qw(Chart::Base);
+our $VERSION = 'v2.402.0';
 
 use Chart::Base;
 use GD;
 use Carp;
 
 #>>>>>>>>>>>>>>>>>>>>>>>>>>#
-#  public methods go here  #
+#  public methods          #
 #<<<<<<<<<<<<<<<<<<<<<<<<<<#
 
 #>>>>>>>>>>>>>>>>>>>>>>>>>>>#
-#  private methods go here  #
+#  private methods          #
 #<<<<<<<<<<<<<<<<<<<<<<<<<<<#
 
-## @method private _draw_data
-# @brief
-# finally get around to plotting the data for (vertical) bars
+## _draw_data : plotting the data for (vertical) bars
 #
-# @details
-# The user may define the kind of labelling the data by setting\n
-# 'label_values' to 'value' if she wants to have the absolut values\n
-# 'label_values' to 'none' if she wants to have no values (default)\n
+#  The user may define the kind of labelling the data by setting
+# 'label_values' to 'value' if she wants to have the absolut values
+# 'label_values' to 'none' if she wants to have no values (default)
 #
-sub _draw_data
-{
+sub _draw_data {
     my $self = shift;
 
     my $data      = $self->{'dataref'};
@@ -242,5 +227,4 @@ sub _draw_data
 
 }
 
-## be a good module and return 1
-1;
+1; # be a good module and return 1
